import 'package:equatable/equatable.dart';

abstract class ChangePasswordState extends Equatable {
  const ChangePasswordState();

  @override
  List<Object> get props => [];
}

class ChangePasswordInitial extends ChangePasswordState {}

class ChangePasswordLoading extends ChangePasswordState {}

class ChangePasswordSuccess extends ChangePasswordState {}

class ChangePasswordFailure extends ChangePasswordState {
  final String error;

  const ChangePasswordFailure(this.error);

  @override
  List<Object> get props => [error];
}

class ChangePasswordFieldsState extends ChangePasswordState {
  final bool areFieldsFilled;

  const ChangePasswordFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
